@@ -139,7 +139,13 @@ class TimeForestRegressor(BaseEstimator, RegressorMixin):
         - average_prediction: outputs the average prediction from the
         n_estimators.
         """
-        predictions = [model.predict(X) for model in self.n_estimators_]
+        # predictions = [model.predict(X) for model in self.n_estimators_]
+        if self.multi:
+            predictions = Parallel(n_jobs=self.n_jobs, verbose=0)(
+                delayed(model.predict)(X) for model in self.n_estimators_
+            )
+        else:
+            predictions = [model.predict(X) for model in self.n_estimators_]
 
         if type(X).__module__ == np.__name__:
             X = pd.DataFrame(X)
@@ -166,7 +172,7 @@ class TimeForestRegressor(BaseEstimator, RegressorMixin):
         return (
             pd.concat(
                 [
-                    n_estimator.feature_importance
+                    n_estimator.feature_importance()
                     for n_estimator in self.n_estimators_
                 ]
             )
@@ -211,6 +217,7 @@ class TimeForestClassifier(BaseEstimator, ClassifierMixin):
         min_sample_periods=100,
         max_features="auto",
         bootstrapping=True,
+        criterion="gini",
         period_criterion="avg",
         n_jobs=-1,
         multi=True,
@@ -223,6 +230,7 @@ class TimeForestClassifier(BaseEstimator, ClassifierMixin):
         self.n_jobs = n_jobs
         self.multi = multi
         self.bootstrapping = bootstrapping
+        self.criterion = criterion
         self.period_criterion = period_criterion
 
     def fit(self, X, y, sample_weight=None, verbose=False):
@@ -264,7 +272,7 @@ class TimeForestClassifier(BaseEstimator, ClassifierMixin):
                     row_indexes=[],
                     verbose=verbose,
                     max_features=self.max_features,
-                    criterion="gini",
+                    criterion=self.criterion,
                     period_criterion=self.period_criterion,
                     random_state=i,
                 )
@@ -285,7 +293,7 @@ class TimeForestClassifier(BaseEstimator, ClassifierMixin):
                     verbose=verbose,
                     max_features=self.max_features,
                     period_criterion=self.period_criterion,
-                    criterion="gini",
+                    criterion=self.criterion,
                     random_state=i,
                 )
                 for i in range(self.n_estimators)
@@ -303,7 +311,13 @@ class TimeForestClassifier(BaseEstimator, ClassifierMixin):
         if type(X).__module__ == np.__name__:
             X = pd.DataFrame(X)
 
-        predictions = [model.predict(X) for model in self.n_estimators_]
+        if self.multi:
+            predictions = Parallel(n_jobs=self.n_jobs, verbose=0)(
+                delayed(model.predict)(X) for model in self.n_estimators_
+            )
+        else:
+            predictions = [model.predict(X) for model in self.n_estimators_]
+
         positive_proba = np.mean(np.array(predictions), axis=0)
         negative_proba = np.ones(len(positive_proba)) - positive_proba
 
@@ -342,7 +356,7 @@ class TimeForestClassifier(BaseEstimator, ClassifierMixin):
         return (
             pd.concat(
                 [
-                    n_estimator.feature_importance
+                    n_estimator.feature_importance()
                     for n_estimator in self.n_estimators_
                 ]
             )
@@ -482,7 +496,7 @@ class _RandomTimeSplitTree:
                         min_sample_periods
                     )
                 )
-        elif self.depth <= self.max_depth:
+        if self.depth < self.max_depth:
             self.create_split()
 
     def create_split(self):
@@ -501,7 +515,7 @@ class _RandomTimeSplitTree:
                 self.find_better_split(variable, idx)
         if self.score == float("inf"):
             return False
-        x = self._split_column
+        x = self._split_column()
 
         left_split = np.nonzero(x <= self.split_example)
         right_split = np.nonzero(x > self.split_example)
@@ -516,6 +530,9 @@ class _RandomTimeSplitTree:
             min_sample_periods=self.min_sample_periods,
             time_column=self.time_column,
             max_depth=self.max_depth,
+            min_leaf=self.min_leaf,
+            criterion=self.criterion,
+            period_criterion=self.period_criterion,
             sample_weight=self.sample_weight,
             verbose=self.verbose,
         )
@@ -529,6 +546,9 @@ class _RandomTimeSplitTree:
             min_sample_periods=self.min_sample_periods,
             time_column=self.time_column,
             max_depth=self.max_depth,
+            min_leaf=self.min_leaf,
+            criterion=self.criterion,
+            period_criterion=self.period_criterion,
             sample_weight=self.sample_weight,
             verbose=self.verbose,
         )
